@@ -288,17 +288,23 @@ load_data_decennial <- function(geography, variables, key, year, sumfile,
     vars_to_get <- paste0(var, ",NAME")
   }
 
-  if (year == 2010) {
-    base <- paste0("https://api.census.gov/data/",
-                   year,
-                   "/dec/",
-                   sumfile)
-  } else {
-    base <- paste0("https://api.census.gov/data/",
-                   year,
-                   "/",
-                   sumfile)
-  }
+
+  base <- paste0("https://api.census.gov/data/",
+                                  year,
+                                  "/dec/",
+                                  sumfile)
+
+  # if (year == 2010) {
+  #   base <- paste0("https://api.census.gov/data/",
+  #                  year,
+  #                  "/dec/",
+  #                  sumfile)
+  # } else {
+  #   base <- paste0("https://api.census.gov/data/",
+  #                  year,
+  #                  "/",
+  #                  sumfile)
+  # }
 
 
 
